@@ -13,12 +13,15 @@ from django.utils.translation import ugettext_lazy as _
 from fileupload.constants import UPLOADER_UPLOAD_DIRECTORY
 
 
-def upload_to(instance, file_name):
+def upload_to(instance, file_name, file_name_counter=0):
+    # if we don't persist filename, generate a uuid for the file. Otherwise add a number if filename is already present.
     if not hasattr(settings, 'UPLOADER_PERSIST_FILENAME') or not settings.UPLOADER_PERSIST_FILENAME:
         file_name = "{0}.{1}".format(uuid.uuid4().hex, file_name.split('.')[-1])
+    elif file_name_counter > 0:
+        file_name = f'{os.path.splitext(file_name)[0]}{file_name_counter}{os.path.splitext(file_name)[1]}'
     file_dir = os.path.join(UPLOADER_UPLOAD_DIRECTORY, file_name)
     while Attachment.objects.filter(file=file_dir):
-        upload_to(instance, file_name)
+        file_dir = upload_to(instance, file_name, file_name_counter + 1)
 
     return file_dir
 
