@@ -1,6 +1,6 @@
 import urllib
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 
 def build_url(*args, **kwargs):
@@ -8,4 +8,4 @@ def build_url(*args, **kwargs):
     url = reverse(*args, **kwargs)
     if get:
         url += '?' + urllib.parse.urlencode(get)
-    return url
\ No newline at end of file
+    return url
